import { apis } from "@/apis";
import { useMutation, useQuery } from "@tanstack/react-query";
import { FC } from "react";
import { LinkAbhaNumber } from "@/components/LinkAbhaNumber";
import { toast } from "@/lib/utils";
import { Patient } from "@/types/patient";

type PatientHomeActionsProps = {
  patient: Patient;
  className?: string;
};

const PatientHomeActions: FC<PatientHomeActionsProps> = ({
  patient,
  className,
}) => {
  const { data: abhaNumber, refetch } = useQuery({
    queryKey: ["abhaNumber", patient.id],
    queryFn: () => apis.abhaNumber.get(patient.id),
    enabled: !!patient.id,
  });

  const linkAbhaNumberAndPatientMutation = useMutation({
    mutationFn: apis.healthId.linkAbhaNumberAndPatient,
    onSuccess: (data) => {
      if (data) {
        toast.success(data.detail);
        refetch();
      }
    },
    onError: (error) => {
      toast.error(error.message);
    },
  });

  return (
    <>
      {!abhaNumber && (
        <LinkAbhaNumber
          onSuccess={(abhaNumber) => {
            linkAbhaNumberAndPatientMutation.mutate({
              patient: patient.id,
              abha_number: abhaNumber.external_id,
            });
          }}
          className={className}
        />
      )}
    </>
  );
};

export default PatientHomeActions;
